Types matching the OpenAPI 3.x specification.
Structs
- Components
- Holds reusable schema, response, parameter, and other objects.
- Contact
- Contact information for the API.
- Discriminator
- Discriminator object for polymorphism support.
- Encoding
- A single encoding definition applied to a single schema property.
- Example
- An example value for a parameter, media type, or schema.
- External
Documentation - Allows referencing an external resource for extended documentation.
- Header
- Describes a single header parameter.
- Info
- Metadata about the API.
- License
- License information for the API.
- Media
Type - Describes a media type with optional schema and examples.
- OpenAPI
Spec - Root document object of the OpenAPI specification.
- Operation
- Describes a single API operation on a path.
- Parameter
- Describes a single operation parameter.
- Path
Item - Describes the operations available on a single path.
- Request
Body - Describes a request body.
- Response
- Describes a single response from an API operation.
- Schema
- The Schema Object allows the definition of input and output data types.
- Security
Requirement - A security requirement object listing the required security schemes.
- Server
- An object representing a server.
- Tag
- Adds metadata to a single tag used by operations.
- Xml
- XML metadata for a schema property.
Enums
- ApiKey
Location - The location of an API key parameter.
- Http
Scheme - HTTP authentication scheme (e.g.,
bearer,basic). - Parameter
Location - The location of a parameter (query, header, path, or cookie).
- Schema
Type - Schema type, which can be a single string or an array of strings.
- Security
Scheme - Defines a security scheme that can be used by the operations.