pub fn template(spec: &OpenAPISpec, theme_name: &str, favicon: &str) -> StringExpand description
Renders the HTML template with the given spec, theme, and favicon.
pub fn template(spec: &OpenAPISpec, theme_name: &str, favicon: &str) -> StringRenders the HTML template with the given spec, theme, and favicon.